==> daal-devel-2018.0.0.20170814-0.tar.bz2: pydaal_sources/daal/algorithms/multinomial_naive_bayes/quality_metric_set.py <==
# Copyright 2014-2017 Intel Corporation
# All Rights Reserved.
#
# If this  software was obtained  under the  Intel Simplified  Software License,
# the following terms apply:
#
# The source code,  information  and material  ("Material") contained  herein is
# owned by Intel Corporation or its  suppliers or licensors,  and  title to such
# Material remains with Intel  Corporation or its  suppliers or  licensors.  The
# Material  contains  proprietary  information  of  Intel or  its suppliers  and
# licensors.  The Material is protected by  worldwide copyright  laws and treaty
# provisions.  No part  of  the  Material   may  be  used,  copied,  reproduced,
# modified, published,  uploaded, posted, transmitted,  distributed or disclosed
# in any way without Intel's prior express written permission.  No license under
# any patent,  copyright or other  intellectual property rights  in the Material
# is granted to  or  conferred  upon  you,  either   expressly,  by implication,
# inducement,  estoppel  or  otherwise.  Any  license   under such  intellectual
# property rights must be express and approved by Intel in writing.
#
# Unless otherwise agreed by Intel in writing,  you may not remove or alter this
# notice or  any  other  notice   embedded  in  Materials  by  Intel  or Intel's
# suppliers or licensors in any way.
#
#
# If this  software  was obtained  under the  Apache License,  Version  2.0 (the
# "License"), the following terms apply:
#
# You may  not use this  file except  in compliance  with  the License.  You may
# obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless  required  by   applicable  law  or  agreed  to  in  writing,  software
# distributed under the License  is distributed  on an  "AS IS"  BASIS,  WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#
# See the   License  for the   specific  language   governing   permissions  and
# limitations under the License.


from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_quality_metric_set5', [dirname(__file__)])
        except ImportError:
            import _quality_metric_set5
            return _quality_metric_set5
        if fp is not None:
            try:
                _mod = imp.load_module('_quality_metric_set5', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _quality_metric_set5 = swig_import_helper()
    del swig_import_helper
else:
    import _quality_metric_set5
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


try:
    import weakref
    weakref_proxy = weakref.proxy
except:
    weakref_proxy = lambda x: x


import daal.algorithms.multinomial_naive_bayes
import daal.algorithms.classifier
import daal.algorithms
import daal.data_management
import daal
import daal.services
import daal.data_management.data_feature_utils
import daal.algorithms.classifier.quality_metric.multiclass_confusion_matrix
import daal.algorithms.quality_metric
import daal.algorithms.quality_metric_set

_quality_metric_set5.confusionMatrix_swigconstant(_quality_metric_set5)
confusionMatrix = _quality_metric_set5.confusionMatrix

_quality_metric_set5.lastQualityMetricId_swigconstant(_quality_metric_set5)
lastQualityMetricId = _quality_metric_set5.lastQualityMetricId
class Parameter(daal.algorithms.Parameter):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.Parameter]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Parameter, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.Parameter]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Parameter, name)
    __repr__ = _swig_repr

    def __init__(self, nClasses=2):
        this = _quality_metric_set5.new_Parameter(nClasses)
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _quality_metric_set5.delete_Parameter
    __del__ = lambda self: None
    __swig_setmethods__["nClasses"] = _quality_metric_set5.Parameter_nClasses_set
    __swig_getmethods__["nClasses"] = _quality_metric_set5.Parameter_nClasses_get
    if _newclass:
        nClasses = _swig_property(_quality_metric_set5.Parameter_nClasses_get, _quality_metric_set5.Parameter_nClasses_set)
Parameter_swigregister = _quality_metric_set5.Parameter_swigregister
Parameter_swigregister(Parameter)

class ResultCollection(daal.algorithms.quality_metric_set.ResultCollection):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.quality_metric_set.ResultCollection]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, ResultCollection, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.quality_metric_set.ResultCollection]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, ResultCollection, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _quality_metric_set5.new_ResultCollection()
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _quality_metric_set5.delete_ResultCollection
    __del__ = lambda self: None

    def getResult(self, id):
        return _quality_metric_set5.ResultCollection_getResult(self, id)
ResultCollection_swigregister = _quality_metric_set5.ResultCollection_swigregister
ResultCollection_swigregister(ResultCollection)

class InputDataCollection(daal.algorithms.quality_metric_set.InputDataCollection):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.quality_metric_set.InputDataCollection]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, InputDataCollection, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.quality_metric_set.InputDataCollection]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, InputDataCollection, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _quality_metric_set5.new_InputDataCollection()
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _quality_metric_set5.delete_InputDataCollection
    __del__ = lambda self: None

    def getInput(self, id):
        return _quality_metric_set5.InputDataCollection_getInput(self, id)
InputDataCollection_swigregister = _quality_metric_set5.InputDataCollection_swigregister
InputDataCollection_swigregister(InputDataCollection)

class Batch(daal.algorithms.quality_metric_set.Batch):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.quality_metric_set.Batch]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.quality_metric_set.Batch]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch, name)
    __repr__ = _swig_repr
    __swig_setmethods__["parameter"] = _quality_metric_set5.Batch_parameter_set
    __swig_getmethods__["parameter"] = _quality_metric_set5.Batch_parameter_get
    if _newclass:
        parameter = _swig_property(_quality_metric_set5.Batch_parameter_get, _quality_metric_set5.Batch_parameter_set)

    def __init__(self, nClasses=2, useDefaultMetrics=True):
        this = _quality_metric_set5.new_Batch(nClasses, useDefaultMetrics)
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _quality_metric_set5.delete_Batch
    __del__ = lambda self: None

    def getResultCollection(self):
        return _quality_metric_set5.Batch_getResultCollection(self)

    def getInputDataCollection(self):
        return _quality_metric_set5.Batch_getInputDataCollection(self)

    def compute(self):
        return _quality_metric_set5.Batch_compute(self)
Batch_swigregister = _quality_metric_set5.Batch_swigregister
Batch_swigregister(Batch)

from numpy import float64, float32, intc


# This file is compatible with both classic and new-style classes.

==> daal-devel-2020.0-166.tar.bz2: pydaal_sources/daal/algorithms/multinomial_naive_bayes/quality_metric_set.py <==
# Copyright 2014-2019 Intel Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.



from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_quality_metric_set5_', [dirname(__file__)])
        except ImportError:
            import _quality_metric_set5_
            return _quality_metric_set5_
        if fp is not None:
            try:
                _mod = imp.load_module('_quality_metric_set5_', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _quality_metric_set5_ = swig_import_helper()
    del swig_import_helper
else:
    import _quality_metric_set5_
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


try:
    import weakref
    weakref_proxy = weakref.proxy
except:
    weakref_proxy = lambda x: x


import daal.algorithms.multinomial_naive_bayes
import daal.algorithms.classifier
import daal.algorithms
import daal.data_management
import daal
import daal.services
import daal.data_management.features
import daal.data_management.modifiers.csv
import daal.data_management.modifiers
import daal.algorithms.classifier.quality_metric.multiclass_confusion_matrix
import daal.algorithms.quality_metric
import daal.algorithms.quality_metric_set

_quality_metric_set5_.confusionMatrix_swigconstant(_quality_metric_set5_)
confusionMatrix = _quality_metric_set5_.confusionMatrix

_quality_metric_set5_.lastQualityMetricId_swigconstant(_quality_metric_set5_)
lastQualityMetricId = _quality_metric_set5_.lastQualityMetricId
class Parameter(daal.algorithms.Parameter):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.Parameter]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Parameter, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.Parameter]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Parameter, name)
    __repr__ = _swig_repr

    def __init__(self, nClasses=2):
        this = _quality_metric_set5_.new_Parameter(nClasses)
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _quality_metric_set5_.delete_Parameter
    __del__ = lambda self: None
    __swig_setmethods__["nClasses"] = _quality_metric_set5_.Parameter_nClasses_set
    __swig_getmethods__["nClasses"] = _quality_metric_set5_.Parameter_nClasses_get
    if _newclass:
        nClasses = _swig_property(_quality_metric_set5_.Parameter_nClasses_get, _quality_metric_set5_.Parameter_nClasses_set)
Parameter_swigregister = _quality_metric_set5_.Parameter_swigregister
Parameter_swigregister(Parameter)

class ResultCollection(daal.algorithms.quality_metric_set.ResultCollection):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.quality_metric_set.ResultCollection]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, ResultCollection, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.quality_metric_set.ResultCollection]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, ResultCollection, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _quality_metric_set5_.new_ResultCollection()
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _quality_metric_set5_.delete_ResultCollection
    __del__ = lambda self: None

    def getResult(self, id):
        return _quality_metric_set5_.ResultCollection_getResult(self, id)
ResultCollection_swigregister = _quality_metric_set5_.ResultCollection_swigregister
ResultCollection_swigregister(ResultCollection)

class InputDataCollection(daal.algorithms.quality_metric_set.InputDataCollection):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.quality_metric_set.InputDataCollection]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, InputDataCollection, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.quality_metric_set.InputDataCollection]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, InputDataCollection, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _quality_metric_set5_.new_InputDataCollection()
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _quality_metric_set5_.delete_InputDataCollection
    __del__ = lambda self: None

    def getInput(self, id):
        return _quality_metric_set5_.InputDataCollection_getInput(self, id)
InputDataCollection_swigregister = _quality_metric_set5_.InputDataCollection_swigregister
InputDataCollection_swigregister(InputDataCollection)

class Batch(daal.algorithms.quality_metric_set.Batch):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.quality_metric_set.Batch]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.quality_metric_set.Batch]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch, name)
    __repr__ = _swig_repr
    __swig_setmethods__["parameter"] = _quality_metric_set5_.Batch_parameter_set
    __swig_getmethods__["parameter"] = _quality_metric_set5_.Batch_parameter_get
    if _newclass:
        parameter = _swig_property(_quality_metric_set5_.Batch_parameter_get, _quality_metric_set5_.Batch_parameter_set)

    def __init__(self, nClasses=2, useDefaultMetrics=True):
        this = _quality_metric_set5_.new_Batch(nClasses, useDefaultMetrics)
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _quality_metric_set5_.delete_Batch
    __del__ = lambda self: None

    def getResultCollection(self):
        return _quality_metric_set5_.Batch_getResultCollection(self)

    def getInputDataCollection(self):
        return _quality_metric_set5_.Batch_getInputDataCollection(self)

    def compute(self):
        return _quality_metric_set5_.Batch_compute(self)
Batch_swigregister = _quality_metric_set5_.Batch_swigregister
Batch_swigregister(Batch)

from numpy import float64, float32, intc


# This file is compatible with both classic and new-style classes.
